using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Styles;

namespace GridFilterBarTest
{
    public partial class Form1 : Form
    {
        private GridFilterBar filterBar = null;
        private string _currentTableName = string.Empty;

        public Form1()
        {
            InitializeComponent();
            DataTable dt = CreateNewTable();
            this.gridDataBoundGrid1.DataSource = dt;
            SetTableIntoGridAndWireFilterBar(dt.TableName);
        }

        private DataTable CreateNewTable()
        {
            DataTable table = new DataTable("TestData");
            DataColumn dc1 = new DataColumn("ID", typeof(Int32));
            DataColumn dc2 = new DataColumn("Name", typeof(String));
            DataColumn dc3 = new DataColumn("Employed", typeof(String));
            DataColumn dc4 = new DataColumn("Comments", typeof(String));

            table.Columns.Add(dc1);
            table.Columns.Add(dc2);
            table.Columns.Add(dc3);
            table.Columns.Add(dc4);
            DataRow r = null;
            for (int i = 1; i < 50; i++)
            {
                r = table.NewRow();
                r["ID"] = i;
                r["Name"] = "Test Employee " + i.ToString();
                
                if (i % 8 == 0)
                    r["Employed"] = "N";
                else
                    r["Employed"] = "Y";
             
                r["Comments"] = "comments will go here " + i.ToString();
                table.Rows.Add(r);
            }

            return table;
        }

        #region Filter Bar Support
        private void SetTableIntoGridAndWireFilterBar(string tableName)
        {
            this.Cursor = Cursors.WaitCursor;

            this.gridDataBoundGrid1.BeginUpdate();

            if (this.filterBar != null && this.filterBar.Wired)
            {
                //reset the old table
                this.filterBar.RowFilter = "";

                this.filterBar.UnwireGrid();
            }

            _currentTableName = tableName;

            //create the filter bar and display it
            this.filterBar = new GridFilterBar();

                       
            //create a style for the filter cells that uses TextBox
            GridStyleInfo style = new GridStyleInfo();
            style.ModifyStyle(gridDataBoundGrid1.BaseStylesMap["Header"].StyleInfo, StyleModifyType.Copy);
            style.CellType = "TextBox";
            style.BaseStyle = "Standard";
            style.Font.Bold = false;
            style.BackColor = Color.White;
            style.Borders.Bottom = new GridBorder(GridBorderStyle.Solid);

            this.filterBar.WireGrid(this.gridDataBoundGrid1, style);

            this.gridDataBoundGrid1.EndUpdate();

            this.Cursor = Cursors.Default;
        }
        #endregion
    }
}